=== modified file '.gitlab-ci.yml'
--- .gitlab-ci.yml	2020-06-05 20:08:20 +0000
+++ .gitlab-ci.yml	2020-06-13 11:04:16 +0000
@@ -15,10 +15,12 @@
 
 stages:
   - minimal_build
-  - build
+  - build_prepare
+  - build_base
+  - build_main
+  - build_collect
   - test
   - stage
-  - delay
   - deploy
 
 default:
@@ -37,7 +39,7 @@
     -  ../configure  --prefix=/usr/local --disable-glout --disable-sysinstall --disable-desktop progname="${PROGRAM_NAME}" progtitle="${PROGRAM_TITLE}"
     -  test "x${ARMAGETRONAD_FAKERELEASE}" == "xtrue" && cp ../docker/build/fakerelease_proto.sh docker/build/fakerelease.sh 
     -  cd docker/build
-    -  make gits.tag source
+    -  make CI_prepare -j`nproc`
     -  cd ../../../
     - else
     -  find . -newer timestamp.tag ! -path "./gitlab_build" -exec touch -r timestamp.tag \{\} \;
@@ -49,51 +51,142 @@
      - docker/scripts/.cache
 
 
-# lean tests for non-protected branches
-minimal_build:
-  stage: minimal_build
+# very basic build
+build_prepare:
+  stage: build_prepare
   rules:
     - if: $CI_MERGE_REQUEST_ID
-      when: never
-    - if: $CI_COMMIT_REF_PROTECTED == "true"
-      when: never
+      when: on_success
     - when: on_success
-  script:
-    - cd gitlab_build/docker/build
-    - target=CI_base
-    - if ! make -O -j$(nproc) ${target}; then
-    -   make -d ${target} || exit $?
-    -   exit 1
-    - fi
+  script: [""]
   artifacts:
     untracked: true
     expire_in: 1 day
 
 
-# do the bulk of the building
-build:
-  stage: build
-  rules:
-  - if: $CI_MERGE_REQUEST_ID
-    when: on_success
-  - if: $CI_COMMIT_REF_PROTECTED == "true"
-    when: on_success
-  - when: manual
-  script:
-    - target=CI
-    # check if (fake!) secrets are available, if yes, copy them and build debtest
-    - if test -r /secrets/sec.gpg; then
-    -   cp -a /secrets gitlab_build/docker/deploy/
-    -   target="debtest.tag CI"
-    - fi
-    # build
-    - cd gitlab_build/docker/build
-    - if ! make -O -j$(nproc) ${target}; then
-    -   make -d ${target} || exit $?
-    -   exit 1
-    - fi
-    - make artifactclean
-    - cd ../../
+build_server_32_raw:
+  stage: build_base
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh -k result.build_server_32
+  artifacts:
+    paths:
+    - gitlab_build/docker/build/*_32
+    - gitlab_build/docker/build/result.build_server_32.dir
+    expire_in: 1 day
+
+# It seems like GitLab CI, all else being equal, schedules jobs in the order
+# listed here. So list the ones that take longest first.
+# Windows builds are worst because they have an additional layer of emulation,
+# are not parallelized and are client and server build in one.
+build_windows:
+  needs:
+  - build_prepare
+  - build_server_32_raw
+  dependencies:
+  - build_prepare
+  - build_server_32_raw
+  stage: build_main
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh CI_windows
+  artifacts:
+    paths:
+    - gitlab_build/docker/build/
+    expire_in: 1 day
+
+# debtest is faster, but also not paralellized
+build_debtest:
+  dependencies:
+  - build_prepare
+  stage: build_main
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh CI_debtest
+  artifacts:
+    paths:
+    - gitlab_build/docker/build/
+    expire_in: 1 day
+
+build_client_64:
+  dependencies:
+  - build_prepare
+  stage: build_main
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh CI_linux_client_64
+  artifacts:
+    paths:
+    - gitlab_build/docker/build/
+    expire_in: 1 day
+
+build_client_32:
+  dependencies:
+  - build_prepare
+  stage: build_main
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh CI_linux_client_32
+  artifacts:
+    paths:
+    - gitlab_build/docker/build/
+    expire_in: 1 day
+
+build_server_64:
+  dependencies:
+  - build_prepare
+  stage: build_main
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh CI_linux_server_64
+  artifacts:
+    paths:
+    - gitlab_build/docker/build/
+    expire_in: 1 day
+
+# this one is special, it can rely on previous build work
+build_server_32:
+  dependencies:
+  - build_prepare
+  - build_server_32_raw
+  stage: build_main
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh CI_linux_server_32
+  artifacts:
+    paths:
+    - gitlab_build/docker/build/
+    expire_in: 1 day
+
+build_collect:
+  stage: build_collect
+  rules:
+  - if: $CI_MERGE_REQUEST_ID
+    when: on_success
+  - when: on_success
+  script:
+    - gitlab_build/docker/build/make_ci.sh debtest.tag CI || exit $?
     - rm -rf src
   artifacts:
     untracked: true
@@ -101,10 +194,9 @@
 
 # deploy to staged environment
 deploy-staged:
-  needs:
-   - build
   dependencies:
-   - build
+   - build_prepare
+   - build_collect
   stage: stage
   tags:
    - armagetronad_deploy
@@ -127,13 +219,8 @@
 
 # do the actual release; manually for final releases, delayed to avoid spam for everyone else
 delay-release:
-  needs:
-   - build
-   - deploy-staged
   dependencies: []
-  stage: delay
-  tags:
-   - armagetronad_deploy
+  stage: stage
   rules: 
   - if: $CI_MERGE_REQUEST_ID
     when: never
@@ -148,11 +235,9 @@
 
 # do the actual release; manually for final releases, delayed to avoid spam for everyone else
 deploy-release:
-  needs:
-   - build
-   - delay-release
   dependencies:
-   - build
+   - build_prepare
+   - build_collect
   stage: deploy
   tags:
    - armagetronad_deploy
@@ -184,9 +269,9 @@
 pack:
   stage: stage
   needs:
-   - build
+   - build_collect
   dependencies:
-   - build
+   - build_collect
   script: [""]
   before_script:
     # test that everything has been prepared correctly
@@ -219,7 +304,7 @@
 
 # for local testing
 complete_build:
-  stage: build
+  stage: build_main
   rules:
   - when: never
   script:

=== modified file 'docker/build/Makefile.am'
--- docker/build/Makefile.am	2020-06-11 20:12:05 +0000
+++ docker/build/Makefile.am	2020-06-13 11:39:15 +0000
@@ -6,6 +6,15 @@
 default:
 	echo "Nothing generic to do."
 
+# individual targets for split jobs
+CI_prepare: gits_artifacts.tag source make_ci.sh rootcontext.64
+CI_linux_server_32: appimage_server_32.tag apptar_server_32.tag
+CI_linux_client_32: appimage_client_32.tag apptar_client_32.tag
+CI_linux_server_64: appimage_server_64.tag apptar_server_64.tag
+CI_linux_client_64: appimage_client_64.tag apptar_client_64.tag
+CI_windows: winzip.tag windows.tag
+CI_debtest: debtest.tag
+
 # full open source builds
 free.tag: appimage.tag apptar.tag sourcetar.tag
 	touch $@
@@ -15,16 +24,15 @@
 closed_regular.tag: windows.tag winzip.tag
 	touch $@
 closed_regular: closed.tag
-closed_steam.tag: steam_windows.tag steam_linux.tag
+closed_steam.tag: # steam_windows.tag steam_linux.tag
 	touch $@
 closed_steam: closed_steam.tag
 closed.tag: closed_steam.tag closed_regular.tag
 	touch $@
 closed: closed.tag
 
-
 # closed comes first because windows builds take the longest and are not internally parallelized
-full.tag: result.winsource_32 result.winsource_steam closed.tag free.tag
+full.tag: result.winsource_32 closed.tag free.tag # result.winsource_steam
 	touch $@
 full: full.tag
 
@@ -33,11 +41,11 @@
 	touch $@
 
 # minimal expected build to be packable
-CI_pack.tag: gits_artifacts.tag source.tag CI_base.tag free.tag upload/PATCHNOTES.md
+CI_pack.tag: gits_artifacts.tag source.tag CI_base.tag free.tag upload/PATCHNOTES.md upload/CHANGELOG.md
 	touch $@
 
 # all windows builds
-CI_windows.tag: CI_base.tag steam_windows.tag closed_regular.tag
+CI_windows.tag: CI_base.tag closed_regular.tag # steam_windows.tag
 	touch $@
 
 # all free linux builds (so, no steam)
@@ -113,6 +121,9 @@
 	mkdir -p proto
 	echo > $@
 
+make_ci.sh: ${srcdir}/make_ci.sh.in
+	cp $< $@
+
 context/version.sh: ${srcdir}/context/version.sh.in
 	cd ../../; ./config.status docker/build/context/version.sh
 
@@ -163,6 +174,9 @@
 upload/PATCHNOTES.md: sourcetar.tag upload/.tag
 	${top_srcdir}/batch/make/patchnotes.py ${top_srcdir} ${top_srcdir}/CHANGELOG_FROZEN.md armagetronad armagetronad -p > $@
 
+upload/CHANGELOG.md: sourcetar.tag upload/.tag
+	${top_srcdir}/batch/make/patchnotes.py ${top_srcdir} ${top_srcdir}/CHANGELOG_FROZEN.md armagetronad armagetronad > $@
+
 #***************************************************************
 
 # generic context with source
@@ -202,8 +216,9 @@
 	echo > $@
 
 # add debian/ubuntu build info for release %. Requires GPG key from ~/.gnupg
-context.debsrc_%: rootcontext.64 ${srcdir}/rebrand_debian_core.sh ${srcdir}/debian_source.sh gits_artifacts.tag $(TARBALL) #../deploy/secrets/*.gpg
-	${srcdir}/prepare_context.sh $@.dir $<.dir/'*' $(TARBALL) ${srcdir}/rebrand_debian_core.sh ${srcdir}/debian_source.sh ./gits/debian ../deploy/secrets/*.gpg
+context.debsrc_%: rootcontext.64 ${srcdir}/rebrand_debian_core.sh ${srcdir}/debian_source.sh gits_artifacts.tag $(TARBALL)
+	${srcdir}/prepare_context.sh $@.dir $<.dir/'*' $(TARBALL) ${srcdir}/rebrand_debian_core.sh ${srcdir}/debian_source.sh ./gits/debian
+	if test -r  ../deploy/secrets/sec.gpg; then cp -lrf ../deploy/secrets/*.gpg $@.dir/; fi
 	echo "armadeb_64" > $@.dir/image
 	echo > $@
 result.debsrc_%: context.debsrc_%
@@ -211,7 +226,14 @@
 	echo > $@
 
 # test build a debian package (with a really old ubuntu codename)
-context.debtest: result.debsrc_dapper
+context.debsrc_test: context.debsrc_dapper
+	${srcdir}/prepare_context.sh $@.dir $<.dir/'*'
+#	extract fake secrets
+	base64 -d < ${srcdir}/../deploy/anonymous_secrets.b64 | tar -xjf - --one-top-level=$@.dir
+	mv $@.dir/secrets/* $@.dir
+	rmdir $@.dir/secrets/
+	echo > $@
+context.debtest: result.debsrc_test
 	${srcdir}/prepare_context.sh $@.dir $<.dir/'*'
 	echo "cd source && debuild -i -us -uc -b && rm -rf *" > $@.dir/build_deb.sh
 	chmod +x $@.dir/build_deb.sh
@@ -243,15 +265,6 @@
 	echo "client" > $@.dir/serverclient
 	echo > $@
 
-# OPTIMIZATION:
-# delay build of things not needed for windows or debtest
-# windows needs build_server_32, so do not delay that
-result.build_client_64: | result.build_server_32
-result.build_server_64: | result.build_client_64
-result.build_client_32: | result.build_server_64
-result.build_server_steam: | result.build_server_32
-result.build_client_steam: | result.build_server_steam
-
 .PRECIOUS: context.build_server_32 context.build_client_32  context.build_server_64 context.build_client_64
 
 #***************************************************************
@@ -335,13 +348,13 @@
 APPIMAGE_SERVER_32:=$(APPIMAGE_BASENAME)Dedicated-32bit-$(PACKAGE_VERSION)
 
 upload/$(APPIMAGE_CLIENT_64): result.appimage_client_64 upload/.tag
-	ln -f $<.dir/AppImage $@
+	cp $<.dir/AppImage $@
 upload/$(APPIMAGE_SERVER_64): result.appimage_server_64 upload/.tag
-	ln -f $<.dir/AppImage $@
+	cp $<.dir/AppImage $@
 upload/$(APPIMAGE_CLIENT_32): result.appimage_client_32 upload/.tag
-	ln -f $<.dir/AppImage $@
+	cp $<.dir/AppImage $@
 upload/$(APPIMAGE_SERVER_32): result.appimage_server_32 upload/.tag
-	ln -f $<.dir/AppImage $@
+	cp $<.dir/AppImage $@
 
 appimage_client_64.tag: upload/$(APPIMAGE_CLIENT_64)
 	echo > $@
@@ -441,10 +454,10 @@
 WININST_SERVER=upload/$(WININST_SERVER_NAME)
 $(WININST_CLIENT): result.wininst_32 upload/.tag
 	rm -f $@
-	cp -l $<.dir/$(WININST_CLIENT_NAME) $@
+	cp $<.dir/$(WININST_CLIENT_NAME) $@
 $(WININST_SERVER): result.wininst_32 upload/.tag
 	rm -f $@
-	cp -l $<.dir/$(WININST_SERVER_NAME) $@
+	cp $<.dir/$(WININST_SERVER_NAME) $@
 windows.tag: $(WININST_CLIENT) $(WININST_SERVER)
 	echo > $@
 
@@ -623,10 +636,10 @@
 
 # keep the artifacts clean of junk not needed in the next phase
 artifactclean:
-	rm -rf context.*.dir result.*.dir source proto/*.dir
+	rm -rf *.dir source proto/*.dir
 
 clean: intermediateclean
-	rm -rf upload source gits result.* *.tag
+	rm -rf upload source gits result.* *.tag proto
 	if git -C ${srcdir} rev-parse --abbrev-ref HEAD > /dev/null; then rm -f CI_INFO; fi
 distclean: clean
 	rm -rf $(TARBALL) CI_INFO

=== modified file 'docker/build/build_in_container.sh'
--- docker/build/build_in_container.sh	2020-06-08 22:27:02 +0000
+++ docker/build/build_in_container.sh	2020-06-13 11:39:15 +0000
@@ -21,9 +21,6 @@
 ${wd}/../scripts/ensure_image.sh "${base}" -d
 . ${wd}/../images/digest.sh "${base}" || exit $?
 
-# start daemon on demand
-docker info > /dev/null || { systemctl --user start docker; sleep 5; }
-
 dockeruser=`docker inspect --format '{{.Config.User}}' ${REGISTRY}${base}${REFERENCE}` || exit $?
 home=/home/${dockeruser}
 if test -z "$dockeruser";then

=== added file 'docker/build/make_ci.sh.in'
--- docker/build/make_ci.sh.in	1970-01-01 00:00:00 +0000
+++ docker/build/make_ci.sh.in	2020-06-13 11:39:15 +0000
@@ -0,0 +1,34 @@
+#!/bin/bash
+
+# Helper script for building, just calls make <args>
+# Optional first argument: -k, keeps intermediate directories
+# (default: delete intermediates)
+
+set -x
+
+keep=false
+if test "$1" = -k; then
+    keep=true
+    shift
+fi
+
+EXIT=0
+
+pushd `dirname $0` || exit $?
+
+# first make run
+if ! make $*; then
+    # try again with better debug output
+    make -d $* || EXIT=$?
+fi
+
+# remove heavy intermediate directories
+if test ${keep} = false; then
+    make artifactclean
+fi
+
+popd
+
+# communicate final make return
+exit ${EXIT}
+

=== added file 'docker/deploy/anonymous_secrets.b64'
--- docker/deploy/anonymous_secrets.b64	1970-01-01 00:00:00 +0000
+++ docker/deploy/anonymous_secrets.b64	2020-06-13 11:39:15 +0000
@@ -0,0 +1,104 @@
+QlpoOTFBWSZTWWGRinoADcT/hPiQAQBAG//iP///8H////AAAgAIYBNfb7NNd9PufPe3uu92va77
+d6fW1q29t7yznu689fffa71r1t89e7617fXbMvvfY+e+vb2n3ut9l7X0d3dryvdxviKp41MJiYjC
+aaYEwCMJgExMpQgAIqaYIyYCMmIwgwNGgJjUZNSRA0ephqpkyaYnqZI8EwEwTI0xNDRgmpioAAao
+Qyap7TADSaYIap+pmgxoBMmik0AAaqE8AmyNE1PIJsCaaaB6mRT9MCJIAAahAENGmmnqGj1J6aZT
+NDARop+jRNIT1PU8UtJ+WC/gDtxUipDLEIQA5ymWIQ65SNKpgKEJgIUhHAAlsTALh5Xf7lznHnFL
+nm1he8YrQtc3/FAaInXBjztCKwspm5wf/vWdmBV4v5UQfQ46R+9eZ0EjvUYeaIGmcdelrBfatPGi
+zlhuyHUy2QlCWB98fBxf3Dz8sY/i5loJSSAhiZwIJAVk5S+QFdu3R9u0OaY/+R7QfQqs1/H3upYv
+e8gePI3U7V0exxCYcubWJOT7z1O/Ax5NKFHDBim3aaglT+0Sm7xvn/1UsGUe2sXF9TJP5vxKMnbq
+Wg1AA2bgPwMDbFChVvYA1iarb95h86i3rl3ZLP1/B7MqbD4cVUAtYTnP4O0swKQxFqGUNWh76RLW
+h6p+3eHwaT1muDT+wl0GUTKKU8hSSaQMLXO4iUrz2jn8CTBG6VgewQZJZcoyElsQn/MQKoBk3jF5
+IAkCMmIYEby+/4j0JZmnrcmNNCuXh6jVlLgjpcYy8le2oejmiTOHB7+ZsMGhXlgWudB9ivr3dkBA
+KWgHstX0WkhubAC7plrhG8VFL8vguT4NtRwZY0MkqNiagwYSTjbJwMbg/lS6A4XGQzo+3j6iw/MQ
+9Ff0OVeIbGe/rdXb/T901/8/Ze04elAOfR+dHZP6uy1+RLS44KhxGJM4uuGoPDB8/CjxI4RWtaiO
+c1nIQ9bl/tJkCDpyMAgHG/mgq3mO6igiDBiRxE0ORFm9jjeEUf0kWUCM/GAUW3fi7gIFFwv1HBSx
+eTwD4vcWG45bBVrbuDj3M89m4iENP4U6pDT35Ky1x8CiHIsN14cXlAzRokAoU9DRZtYpwCiJnHK6
+84HUEK8rGeANG7NZ5MnJMSZHcJmkOoNH/AGYIqd/tIJBHtStXeHOHA9kHh+R7kRd8eMXJQMm03Wz
+2ExxogvzI0WgmRIbZsmwORDEgXsRBItS4gDlNZveESLunzJn/gHmrjmnyy8c1jLI91zPJgmv+r1X
+w5o371jp5xC7pXCivZ/HxZC/jC0PnJ42HEzu77usMqOgzXXg/hG8wJ6SXv+QXTZaiX5K1faPYXW0
+4jwIqGv1Rv0sH8neaZQ2P+hOUGxWLrjT9UQsBg3mJURCGvRZjVPtXPPvpD3E0eUm8+zIesXd07xJ
+p6DvJNMBSPdmfxcLcCLr1s/RKN8zfEaH2wtt/HwRR+uj9NnwK97kq6YPjjSHwqubReegLMs1McTr
+GaadwPvxH4b5grzNF0e4xto6BCkdbVdx1XwxrGqnv7L3JX6D32OmwL+65dfIF8nMEOti6sPGvvCf
+zrKZPQKRWnlx0vjshw7KviHAx573dbPSrZq1eCgROIdbTBL4JO7RvvQnYtB9gmfbsIYRxj30ZzdQ
+1rFWHBeZpNs6bP2tkEe3nULqoW7q3JI0ewKzJkOhnyzFefZZCUfCX1pPhUVOBspDuo6D8A0H/fBZ
+ylhEqWVfOwcofGe8USnA6vwLH2pR0L03BupPvLeGKxxUXk6ERSidw+1mWGqfgtQeeVc7jzbMl3b1
+i66iiI6zTPfeV/G4XCF3RJU1EkCL9s1AswdFBMCnp+Un6ssereu+WGeOXDFWpKGdQ9LywnIUbV5r
+c7vXqcr8V6XTv9JVgYGLdmoWrOPUOUoPvIoK1reynjVjVnWHjRbzZ71izMMTiGrzU6pQlT67m51I
+BQkbhUk6IS1rVvJBH77MkHjmsmwijxnYIf8KYKxxO7sK2kkIwikpHGoHkH/HdkzQnSXcxGWYwHp+
+cPcHb4qn5IgDMik/IY+i90uyqRGdj1WBlkqDplc231nz5ZQTd5DuKq8dWtI91Z4NI7x7+nctw6Fl
+rlcXeqr+dD/4D8wZMUPry6iWSEgq/IChAX10457GHATQchlPsmaYi8Kl3YUyacZWzaJwTJkeQ7jb
+YQVcU0sLTDTKIu/3mmtbwv0N/f2AM785X0Oe8+D1AMofBI4ZyVSmYL4ac9nq1m0HB8X65fqQWgEf
+k1ENjdoXzrFQj2iz9hoIwJraJK1LAzITPBb87Hxa4CKSqxUQInbp1lLHOeW9twJ/m64h3fA+M7fX
+Ppg+QX5qkh0C2izPBbb4qs84D/4xxRuxjindFOjFFRxISGQMC4Ny8m59MBcHd4sOjlGjiF4WtLp9
+XoSYWjur2nrebbI7AbhfFViEZk7srWF0T5jD+LwnNE2n7ChiSoOiEx4wXkqX8OGc78gwz25z4xP7
+0toRQ7hi1M+eXSlSiTRGsSQrcL3jWmSUhl2uQEuMO36fAI26qYBwADIMi19CKi3mkv0vtALdC1vu
+YeT4oMjzvl1NIF0q1VHnUdbQIdIwWa3JXwjzqu+RUmV2gr9T+r5UeWIYaUze2LKJ2GuL+2uiyVB0
+ZZ5b33L0EwJnczRogJxrFBZ1krtrXaIlWzyZ3kvWmsgvUXdELq/T1NFbSpPuZgN4At7FZNTN42Al
+9cnyMq3xEQVt8oACKb5yAGkkWmoScx697gt5kN4jcRu8Om4q5Z+0BxItuo54sM2TDaHM6r97Bk4b
+sC5uC9mCylhcmpVTLkVGblu0O5u4ISNwyA7bJED2rK3wUvrK5JxlMhy2BU4IHmKNa5YQ3OXM2iVU
+KGvrL22mZNku8rCpC7PsoMEqHYezJD2cvPsNxCB1bFJVQ+y3FKy1K4Zgf7loCt6mgFCmqJuD21JY
+Dd3q6IoXx8OpG01G3wI5cx2hc1ZT6/GgeII6JyA0nRZiXkdGMDYkE4H5/y6FJIh6C2/UwFaw+iBK
+xpitAgwFzAuxsLLyaB+g3L37jWB4SD41tfDa8jCgIFvCjgcmDX5OYaOhOoNqnvvzSDvpQqD9qvnq
+mHn0q/ThcqLVV+sx0KYp6palpCHpsuNSVA+ZixwbgegSmM5W+4rkSH3ZjEO5wV5v25DJwCFxQDU3
+353B0PVFzjtDNCfAq7Lz4dXCOYrgGxqmipHsBBfqje6Ml+IT+sX3gm1stgkQbmLIbvwG9AsQiaHU
+bQ+D7Lq3cabBfdCGb9tnr4WsnoHuNwRyAr5C+MRr99iB842FXkmsSupIGS9UJQ2Z2rmh6SyDHOEf
+Lolsb4x+TubR8Zera8j+1eY4OpDYhOk2+D1mekqg3DQ0MOlAiTZWT8PNTirJaG9A9ahYvHEDTSyj
+XDqcn183mTWYJWFkE2uQTvenZk9zRGz0sfrspjf2DnWPl9n/WcMcl6PcY3rMJooLBMOrV3fkXzeG
+sWBPD9bO8TSGlA+CquWZxrPZPYL64y+AYhytBONUXR/296AbdM6BgenHpGkld7Zm33EWcRF99MFh
+r4xqgQbV5FxZT6j43NfOixSRivI4+BsyXOMj4VjzYwW8Mb4wTR9/kDNZEzcbgOcp/1U+HoeVwxfD
+3nqzBgkQvWt9LLentBrHyobYWv1qVYv9Pv9rj4Qe27hTTIVVynPTtwqVV8pYRskhREkwBVfVzWqR
+tmZSD5hdzQx/q7EOenyBBz2ahLojO518Li+6kpe6qYPYJsNkL7gPlxQftbltckjupn3NwY2JB6Zd
+IWU8HKaRgq6PPaH6m9RRjA8uf5Gsg5BTtcg1wyPupHX2Lk5pb6i51xb5UVRU3vJ3zqUs0JdXN3tO
+jttxvlrKn2kEbC9P2vhaTUN2D3FeUJpiBIzhorZO3oAuwXxO7XmsUUJXH1h65k97KCIqUAciLykR
+W5ib6aI6ZX6GnIXStWiVzWoLX7Fg0ImskpoFrPY1Q9hxc+l/D8t47VEUqIHE7Lz5hMOfWliCl8gn
+GmeFewdYXjFA1rCDewUtAfBmFCWUmjVPF7FtFwFT/iSnnrFFkCg7XjLo9tfYnjlXlfEwY6rDXRvV
+rqUvCNRqkbqqu83hjJg9A49v7c+PDYu481DTkETbQkVB07QLIlnj4Ul3vjGGXuurQSkAPCmI1lWA
+Bh/dMMAtggTRpkt1t+M6SPg/QN9MMmXuCmb32Y0n2pT+gr93ZlJ5SwsddlBKcvgVdL+3PHT2fosf
+3x9eOYyN5z2GabGN5SemoeYiWlCow0c1qLsyaxZygiSTF5/3E7UV/2eaj5220H6b1yvJ36vEIVGs
+VKakfmbqXjE9IS9ktV2ZpPl9SUkWOPN9yi0Nd5O18pQlAbaKKs9iPOJHzrCveLs4KhYNAVBOXq+4
+KbeVliPe/E9aHAzs31UjJbAQybZ15M9geWvH0gVegcwxSZorm4h0QaDN9yTe5LZjfcIWf0/rufm8
+xPHitniozDksYCSTtNdeGQtZWOiBZ/XljCu8RAas/XiIJZ+QSNHjzr0mmlDPqIjR5WcT7/I1at6Y
+axyHvEtH3t+zG7PifX64hnIBG/sFwguIDJeXee+5Cu7tw3QvKa196g6x9NE0CSnm96YUGfPEekHZ
+UO6svjOLrfbBMJ9GlPQCE34r18GNeOx3QIX2YJExIXzHHgurikXbEhTariFziotQGl2AM7W0L7+3
+V1sZBjzG2pFolfy+pHqhpXhKfk1Qcxd66LxFc2U3HcvNLO818yYT9HJcw7EV6MmRQ37zeaZaXmgj
+yoZrX9Z0K/EiWtN0a88Zjnm6dVlVU6Ja3FyoYp5xUGzm4F3jMNqa/RrQPbEPD3miZdbU8KhOg0Cq
+QNRx90GlBYoXWOcaR7jsTfC5jzl9pjImiXxpPerRHgM0xyXPbEbKJwZsw9ZsODmNSuONpcrGDK5v
+R7bjenZlqcXfPABIDoh7k81oaBESNgO6ydLfWjDmr0shRzwWkJ18mo99Ci/NncH5KFeVe40GdKVl
+jCHs4cB4vIhWCY4PlCSEJje4u6jRwsEisUqCj0OO2snjKsore6x4MgkcuWMG8mNtY0S9s/DXu9TO
+uCgVwwv8NRdkfTkzxumx3A5lr3xS3ky+Z4PEkLrXzYu1Y7e4GGgrDjqL9axZTtcCcPCSSDDJvpMl
+gOknE3JNRrTXylMrAbuzTeDgyy4Nes1dDAWejZFhj9HHlAm8qpW31cW9PHMZgoxpaweX+QK5VNN6
+2+oReg5AIc7uan4kpfmxCgxwUAw5zK4Kn1wmSEn0KH3BjBXZwmWJbU4noTeUUMGeXKY3AnP6JXTj
+FQ2iyp51mVFQ11i0xKmqfKN58HUDEI9qBORxnCVHctqets/DuHEYS1uoA467pvTKjeaRdBmqTZ3Q
+mzyGUSKz4IKrtYxA+0hQ1SlMaFK9LGejyJWyBnJI7OzlbXul3hrWuC3oNk2EY8XQ+Yd7umZrAuig
+4cnSktdjtW7LkEByk0a4o/MP4H5URRVlJF4wcd2rFNNnnfSv2nYFFJ6LndZAfdhrgsUchs3u7rIR
+o6iq+4g95L0Z5IB4XCSwCwvhPhHqZWtVyiNMUc053wFkLyWn1pVk9HX7PlhvFzEIFYcSBUl9WH8G
+s/31JFsjKO4STg6ph71xQOQd2lqlSR+kvq7wm2vo3PVnjnwzh389Par13w0aN6qlquD0BVB8gFlM
+XpF7lXnXf2ErIbEbcVfLBAKIaTkVlcTWWWe1MJcFELDavlvLFdWF7sTa5hficDit9hbrBfUXabvO
+vjpYYA+CnHcjDQoOeY7ue3etpu/vWlF5GnYwlgh+LsuyOMGug9+HB4DgRULtW+MlG5X5hF1Y4kcv
+EWvStPHCnvdFcLE1h8N6lUwRkTn3LUeHvGWbqT0gJL9iBR5RPR6i1c7PMeoa2AoHBQXcPZ8L6tjJ
+frFtkTtubnw/WZE5gM3xba70s4RK3pp3OZj5g5ZN31IDjXdfkE7SiGIcFGvAKvU2652R0hian9e0
+blVgjGoRI2QSjzWg4tMtFxKVNR8uwqpuUZedBa5cr/48g99FrovcO+oDbFJjXGFLEnuYcGBVR5Mu
+9vU1q4HshRnlfq1NwdXtT4QG5zwsyCzjC8jjLdKZvo/e6B+3E4y9dypUE2F2FgC6wRIaR9YzPgdD
+08lxW9E6Ka6w2QCw1IA4XVw6/XvWkO1kuMBnF+Eq7qshpfBV6QHP92GcvTSo8bLrwICcgs0GNyA+
+Ju6rw0B90s1NaKUHocQMU+1mdOF44puaVg/kbA7PXnYtIEui5yId8F+ydJFihkNVFm8OHehNfThv
+ZI78csJS1EOQ0WjQFjkKWhSPwvOXe0JB5iHHm4ltLcqQlXCoPHnnXraVBZsh+Xo8VWzhsikJ9E18
+k8MlgkQ7fw4dNy9bO1ox74/TSpHTKrlmqI8WZUyiNaok1A4SDAwRqJo+Di3ENkpLTMLh773scnQc
+FXFuTYS26uyXAe2789etXzaaVjMNsZF3hIcn5Jkxe8vBwHDIeCyybugnqLc3ZEtLo+LbAcqDDizy
+yuBbk5vXbd6oj9RLJh20vX4uA8BP7HsrkAmDAURP24PWdDJV/k6HCGouAAQwIiGi67Peb6UzTokQ
+P/a+e/WXjlWz17RsNR/AL8twrfWxVi+9gxZ107R01YGeWY3lkdE7qITMtzR6N7F+dXpYExdVkesf
+qTesZ7C3tdIHyTaF/qL0444T6wh7rfwyFyiBsrTmWS+oN0AIAouic0vYT1DZkDYg97YLfJcRgbhI
+S6V0eqZ+ME/hNVTql38NFmJtOrwXCSLNq329Zl8WvYscN6cZSDk2EDMMCRdTpeE4Keds/ZWxjpWY
+X0jmU6OJN8cUnRDcB1rggzQOfS4aqGES2plV59jGnlwNX8OaFvQkA0IwiHBl5vmi8awSq88wFSSE
+DqtldP1ho/d60ph7t8AMoFotDaJuHvnLQUVpbcfC9tB4pNm72thGGdUAc4xDd8Ryy6zSc+NL6r1S
+d+LZwc2SaWUXtHcdiwIed6Bc0G12P61wrFqzGGMwV18pf3/Vt7BM6wi/qLDLaObjlzc3w6bhhhqX
+o9GcYFHCa+5NulIoQev7cZQJaY3cI4iirWkYG36GoQtGo+s4HbJtAlxwyVhprb31fH7/r8Hlitfa
+UGeeGuDOS3JEDs75KifY8zAkHFq8d3ltIfe1vwGyOlGPwqnvzs2fg9VsHpQpkBWHjl5kH4jH1PUr
+Fdt1FrcnbFPOjLmu3WCILES4gzJHdtBV2rrYxVUdbYo90jLB+CXuURw1FZE7ZACccP7oYjidu//s
+jGWMSQLZ9ZaA8MkgryS8qjDl4RZC2YPO2U3qCDh+cvnezOHqnSxGpspHwYGa5k8eriiLHEng8W7M
+oRTFjsnv9PmctfVmSGUYT9H3pjdwLIXXoXcV8RwiXeGiixvdj1z+rID52H/yTD1ZwWsOkY/L5r3Y
+TKo9ZcN6wmOK7+G5ZZIvu0n0/HKVFDOnc0ibBmkaqyKpaMjVQQU1eXGyMhJeWrbpLxgEDVvr0Fkg
+Ca3zxNVM2+bDB1Az7EqNI5pUnx1bdYesQaqlLcfHT3StOSotHIatA8MxHTi7yEphifKG6SFk6aSC
+x71moIGvSFRyrdIzpZYPVtR/FtRpQKq9/ys8JA06JzwbTJgfZavyDCDKCIHaPVcmBQHkDAeJb04p
+VrNICw+CvB1ERNsL153WbkNUFeZCo3XgHgDtoB9mdm7w60yOrtwLSPl6nCPCecgNiJ6YtK6yDq3c
+DwI5tn3IyhT0b75Q+9+dofSYoixBgh+edg3/SZu+vZAqx0Dqb6TOGwIIo+5yl2+w9Jxzsbbde21S
+677efR/CE/8XckU4UJBhkYp6

=== modified file 'docker/deploy/deploy_lp.sh'
--- docker/deploy/deploy_lp.sh	2020-06-01 08:21:51 +0000
+++ docker/deploy/deploy_lp.sh	2020-06-13 11:39:15 +0000
@@ -27,7 +27,7 @@
     echo "Just staging, no upload to Launchpad"
 else
     EXIT=0
-    for f in upload/*${PACKAGE_VERSION}*; do
+    for f in upload/*${PACKAGE_VERSION}* upload/*.md; do
 	if test -r $f; then
 	    ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f || EXIT=$?
 	fi

=== modified file 'docker/deploy/lp-project-upload'
--- docker/deploy/lp-project-upload	2020-06-12 13:06:43 +0000
+++ docker/deploy/lp-project-upload	2020-06-13 11:39:15 +0000
@@ -131,7 +131,6 @@
         # print basename, thirdextension, secondextension, extension
 
         if extension == ".tbz":
-            file_type="Linux Binary Tarball"
             mime_type="application/bzip2"
             if "_client_32_" in fn:
                 description="Client Linux 32 Bit Tarball for Zero Install"
@@ -146,7 +145,11 @@
                 description="Source"
         else:
             if fn == "PATCHNOTES.md":
+                file_type="Release Notes"
                 description="Patch Notes"
+            if fn == "CHANGELOG.md":
+                file_type="ChangeLog File"
+                description="Changelog"
             if extension == ".deb":
                 description="Debian Package"
                 Linux=True

=== modified file 'docker/scripts/ensure_image.sh'
--- docker/scripts/ensure_image.sh	2020-06-01 08:21:51 +0000
+++ docker/scripts/ensure_image.sh	2020-06-13 11:39:15 +0000
@@ -25,9 +25,6 @@
 done
 echo $$ > ${lock}
 
-# start daemon on demand
-docker info > /dev/null 2>&1 || { systemctl --user start docker; sleep 5; }
-
 function invalidate_digest(){
     touch ${id}/${image}.digest.local
 }

=== modified file 'docker/scripts/test_yaml.sh'
--- docker/scripts/test_yaml.sh	2020-06-01 08:21:51 +0000
+++ docker/scripts/test_yaml.sh	2020-06-13 11:39:15 +0000
@@ -4,9 +4,6 @@
 
 set -x
 
-# start daemon on demand
-docker info > /dev/null 2>&1 || { systemctl --user start docker; sleep 5; }
-
 wd=`dirname $0`
 ref=`git rev-parse HEAD`
 

